.. _tutorials:

Tutorials
=========

This page contains a list of tutorials which highlight some of the functionalities of `species`. The tutorials can be downloaded as `Jupyter notebook <https://github.com/tomasstolker/species/tree/main/docs/tutorials>`_. Please `create an issue <https://github.com/tomasstolker/species/issues>`_ if you encounter any problems.

.. tip::
   Details on the various classes, functions, and parameters can be found in the `API documentation <https://species.readthedocs.io/en/latest/modules.html>`_.

**Fitting model spectra, parameter retrievals**

.. toctree::
   :maxdepth: 1

   tutorials/fitting_model_spectra.ipynb
   tutorials/grid_comparison.ipynb
   tutorials/evolution_fit.ipynb
   tutorials/atmospheric_retrieval.ipynb
   tutorials/emission_line.ipynb
   tutorials/flux_calibration.ipynb

**Atmospheric and evolutionary models**

.. toctree::
   :maxdepth: 1

   tutorials/model_spectra.ipynb
   tutorials/data_model.ipynb
   tutorials/read_isochrone.ipynb

**Synthetic photometry, magnitudes, fluxes**

.. toctree::
   :maxdepth: 1

   tutorials/flux_magnitude.ipynb
   tutorials/synthetic_photometry.ipynb

**Color and magnitude diagrams**

.. toctree::
   :maxdepth: 1

   tutorials/color_magnitude_broadband.ipynb
   tutorials/color_magnitude_narrowband.ipynb

**Data of directly imaged planets**

.. toctree::
   :maxdepth: 1

   tutorials/companion_data.ipynb
   tutorials/mass_ratio.ipynb

**Spectral libraries**

.. toctree::
   :maxdepth: 1

   tutorials/spectral_library.ipynb

